@@ -88,7 +88,7 @@ PkExample::PkExample() : TQMainWindow(nullptr, "Polkit tqt example application",
   grid->addWidget(deletePB, 5, 1);
 
   deleteL_2 = new TQLabel(privateLayoutWidget, "deleteL_2");
-  setCB = new TQComboBox(FALSE, privateLayoutWidget, "setCB");
+  setCB = new TQComboBox(false, privateLayoutWidget, "setCB");
   grid->addMultiCellWidget(deleteL_2, 6, 7, 0, 0);
   grid->addWidget(setCB, 6, 1);
 
